@@ -31,7 +31,7 @@ class Database(object):
     def open_connection(self):
         try:
             if self.conn is None:
-                self.conn = pymysql.connect(self.host,
+                self.conn = pymysql.connect(host=self.host,
                                             port=self.port,    
                                             user=self.username,
                                             passwd=self.password,
